pub struct ExecuteControllerJobRequest {
pub execution_configurations: Vec<JobExecutionConfiguration>,
pub options: Option<ExecutionOptions>,
pub idempotency_key: Option<Uuid>,
pub job: Option<Job>,
pub target: Option<Target>,
}Expand description
A request to execute a given ControllerJob on a specific target with one or more configurations.
This action is atomic in that a job for each configuration will be queued, or none of them will. On success, the response will contain a sequence of job IDs where the number and order of IDs returned will correspond to the number and order of configurations given. However, note that execution in the order of the given configurations is not guaranteed. If there is a failure to queue any of the jobs, then none will be queued. A request must have at least one configuration, otherwise an error will be returned.
Fields
execution_configurations: Vec<JobExecutionConfiguration>One or more configurations against which to execute the provided job.
The response will include one job_execution_id for each entry in this list,
each corresponding to its configuration in the same order.
options: Option<ExecutionOptions>idempotency_key: Option<Uuid>Setting the idempotency key permits retrying failed execute-controller-job requests (or batch requests) without creating duplicate jobs.
If the server sees an idempotency key corresponding to an already-enqueued job (or batch of jobs), it will return a copy of the original job-submission response, i.e., the IDs of the already-enqueued jobs.
When submitting jobs, a failure response from the server always means that no jobs were enqueued, so retrying job submission will not create duplicate jobs. However, if submission fails due to a gRPC timeout, the client has no way of knowing whether the service handled the original request or not, so without the idempotency key, retrying may or may not create duplicate jobs.
Clients should not use the same idempotency key for separate requests. The API makes no guarantees about the server behavior in that case.
A given idempotency key is valid for at least as long as any job IDs generated from the corresponding request are known to the server. For a job submitted as part of a session, the idempotency key will be valid for at least as long as the session ID itself is valid. For all jobs, the idempotency key will be valid for at least as long as the job is enqueued, executing, or waiting for results retrieval.
This field is ignored for requests that are part of a BatchExecuteControllerJobRequest;
use BatchExecuteControllerJobRequest.idempotency_key instead.
job: Option<Job>target: Option<Target>Required by the gateway to forward requests to the correct execution host.