pub struct TranslationOptions {
pub q_ctrl: Option<QCtrl>,
pub riverlane: Option<Riverlane>,
pub translation_backend: Option<TranslationBackend>,
}Expand description
Options specified on RPCs that translate Quil to a ControllerJob. Intended to support custom pre-processing and other translation features.
Fields
q_ctrl: Option<QCtrl>When set, the client program will be pre-processed via the Q-CTRL API before translation.
riverlane: Option<Riverlane>translation_backend: Option<TranslationBackend>The backend to use for translation, to include relevant options. If neither is specified, the implementing service may select the translation backend and options.